@@ -21,3 +21,11 @@ class Service(org.maemo.hermes.engine.facebook.service.Service):
         friends = self.linkedInApi.get_friends()
         for friend in friends:
             self._register_friend(friend)
+
+
+    # -----------------------------------------------------------------------
+    def is_profile_url(self, url):
+        """Return True if this is a URL for this service."""
+
+        return url and "linkedin.com" in url
+
