@@ -7,6 +7,8 @@ from unit.test_gravatar import TestGravatarService
 from unit.test_linkedin import TestLinkedInService
 from unit.test_twitter import TestTwitterService
 from unit.test_hermes import TestHermes
+from unit.test_friend import TestFriend
+from unit.test_phonenumber import TestPhoneNumber
 
 from integration.test_gravatar import IntegrationTestGravatarService
 from integration.test_linkedinapi import IntegrationTestLinkedInApi
